@@ -1,14 +1,64 @@
 package Syndication::ESF;
 
+=head1 NAME
+
+Syndication::ESF - Create and update ESF files
+
+=head1 SYNOPSIS
+
+	use Syndication::ESF;
+
+	my $esf = Syndication::ESF->new;
+
+	$esf->parsefile( 'my.esf' );
+
+	$esf->channel( title => 'My channel' );
+
+	$esf->add_item(
+		date  => time,
+		title => 'new item',
+		link  => 'http://example.org/#foo'
+	);
+
+	print "Channel: ", $esf->channel( 'title' ), "\n";
+	print "Items  : ", scalar @{ $esf->{ items } }, "\n";
+
+	my $output = $esf->as_string;
+
+	$esf->save( 'my.esf' );
+
+=head1 DESCRIPTION
+
+This module is the basic framework for creating and maintaing Epistula Syndication
+Format (ESF) files. More information on the format can be found at the Aquarionics
+web site: http://www.aquarionics.com/article/name/esf
+
+This module tries to copy the XML::RSS module's interface. All applicable methods
+have been copied and should respond in the same manner.
+
+Like in XML::RSS, channel data is accessed through the C<channel()> sub, and item
+data is accessed straight out of the items array.
+
+=cut
+
 use strict;
+use warnings;
 use Carp;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 # Defines the set of valid fields for a channel and its items
 my @channel_fields = qw( title contact link );
 my @item_fields    = qw( date title link );
 
+=head1 METHODS
+
+=head2 new()
+
+Creates a new Syndication::ESF object. It currently does not accept any parameters.
+
+=cut
+
 sub new {
 	my $class = shift;
 	my $self = {
@@ -21,6 +71,14 @@ sub new {
 	return $self;
 }
 
+=head2 channel(title => $title, contact => $contact, link => $link)
+
+Supplying no parameters will give you a reference to the channel data. Specifying
+a field name returns the value of the field. Giving it a hash will update the channel
+data with the supplied values.
+
+=cut
+
 sub channel {
 	my $self = shift;
 
@@ -50,23 +108,43 @@ sub channel {
 	return $self->{ channel };
 }
 
+=head2 contact_name()
+
+shortcut to get the contact name
+
+=cut
+
 sub contact_name {
 	my $self = shift;
 	return $self->channel( 'contact_name' );
 }
 
+=head2 contact_email()
+
+shortcut to get the contact email
+
+=cut
+
 sub contact_email {
 	my $self = shift;
 	return $self->channel( 'contact_email' );
 }
 
+=head2 add_item(date => $date, title => $title, link => $link, mode => $mode)
+
+By default, this will append the new item to the end of the list. Specifying
+C<'insert'> for the C<mode> parameter adds it to the front of the list.
+
+=cut
+
 sub add_item {
 	my $self = shift;
 	my $hash = { @_ };
+	my $mode = $hash->{ mode };
 
 	# depending on the mode, add the item to the
 	# start or end of the feed
-	if ( defined( $hash->{ mode } ) && $hash->{ mode } eq 'insert' ) {
+	if ( $mode and $mode eq 'insert' ) {
 		unshift ( @{ $self->{ items } }, $hash );
 	}
 	else {
@@ -76,6 +154,12 @@ sub add_item {
 	return $self->{ items };
 }
 
+=head2 parse($string)
+
+Parse the supplied raw ESF data.
+
+=cut
+
 sub parse {
 	my $self = shift;
 	my $data = shift;
@@ -107,16 +191,19 @@ sub parse {
 	}
 }
 
+=head2 parsefile($filename)
+
+Same as C<parse()>, but takes a filename as input.
+
+=cut
+
 sub parsefile {
 	my $self = shift;
 	my $file = shift;
 
 	my $data;
 
-	if ( not open( FILE, $file ) ) {
-		$@ = "File open error ($file): $!";
-		return;
-	}
+	open( FILE, $file ) or croak "File open error ($file): $!";
 
 	{
 		local $/;
@@ -128,6 +215,12 @@ sub parsefile {
 	$self->parse( $data );
 }
 
+=head2 as_string()
+
+Returns the current data stored in the object as a string.
+
+=cut
+
 sub as_string {
 	my $self = shift;
 
@@ -146,121 +239,37 @@ sub as_string {
 	return $data;
 }
 
+=head2 save($filename)
+
+Saves the value of C<as_string()> to the supplied filename.
+
+=cut
+
 sub save {
 	my $self = shift;
 	my $file = shift;
 
-	if ( not open( FILE, ">$file" ) ) {
-		$@ = "File open error ($file): $!";
-		return;
-	}
+	open( FILE, ">$file" ) or croak "File open error ($file): $!";
 
 	print FILE $self->as_string;
 
 	close( FILE ) or carp( "File close error ($file): $!" );
 }
 
-1;
+=head1 AUTHOR
 
-=pod
+=over 4 
 
-=head1 NAME
-
-Syndication::ESF - Create and update ESF files
-
-=head1 SYNOPSIS
-
-	use Syndication::ESF;
-
-	my $esf = Syndication::ESF->new;
-
-	$esf->parsefile( 'my.esf' );
-
-	$esf->channel( title => 'My channel' );
-
-	$esf->add_item(
-		date  => time
-		title => 'new item'
-		link  => 'http://example.org/#foo'
-	);
-
-	print "Channel: ", $esf->channel( 'title' ), "\n";
-	print "Items  : ", scalar @{ $esf->{ items } }, "\n";
-
-	my $output = $esf->as_string;
-
-	$esf->save( 'my.esf' );
-
-=head1 DESCRIPTION
-
-This module is the basic framework for creating and maintaing Epistula Syndication
-Format (ESF) files. More information on the format can be found at the Aquarionics
-web site: http://www.aquarionics.com/article/name/esf
-
-This module tries to copy the XML::RSS module's interface. All applicable methods
-have been copied and should respond in the same manner.
-
-Like in XML::RSS, channel data is accessed through the C<channel()> sub, and item
-data is accessed straight out of the items array.
-
-=head1 METHODS
-
-=over 4
-
-=item new()
-
-Creates a new Syndication::ESF object. It currently does not accept any parameters.
-
-=item channel(title => $title, contact => $contact, link => $link)
-
-Supplying no parameters will give you a reference to the channel data. Specifying
-a field name returns the value of the field. Giving it a hash will update the channel
-data with the supplied values.
-
-=item add_item(date => $date, title => $title, link => $link, mode => $mode)
-
-By default, this will append the new item to the end of the list. Specifying
-C<'insert'> for the C<mode> parameter adds it to the front of the list.
-
-=item parse($string)
-
-Parse the supplied raw ESF data.
-
-=item parsefile($filename)
-
-Same as C<parse()>, but takes a filename as input.
-
-=item contact_name()
-
-shortcut to get the contact name
-
-=item contact_email()
-
-shortcut to get the contact email
-
-=item as_string()
-
-Returns the current data stored in the object as a string.
-
-=item save($filename)
-
-Saves the value of C<as_string()> to the supplied filename.
+=item * Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =back
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-If you have any questions, comments, bug reports or feature suggestions, 
-email them to Brian Cassidy <brian@alternation.net>.
+Copyright 2004 by Brian Cassidy
 
-=head1 CREDITS
-
-This module was written by Brian Cassidy (http://www.alternation.net/).
-
-=head1 LICENSE
-
-This program is free software; you can redistribute it and/or modify it under the terms
-of the Artistic License, distributed with Perl.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself. 
 
 =head1 SEE ALSO
 
@@ -268,3 +277,4 @@ XML::RSS
 
 =cut
 
+1;
